ProSHADE: Namespace List

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Namespace List
Here is a list of all documented namespaces with brief descriptions:

N ProSHADE_internal_data | This namespace contains the structure and functions required for data reading and storing their derivates
N ProSHADE_internal_distances | This namespace contains the functions used for computing distances between two structures as represented by the ProSHADE_data class
N ProSHADE_internal_io | This namespace contains the internal input/output functions. None of these should be directly accessed by the user
N ProSHADE_internal_mapManip | This namespace contains the internal functions for manipulating maps already present in the internal structures
N ProSHADE_internal_maths | This namespace contains the internal functions for common mathematical operations
N ProSHADE_internal_messages | This namespace contains all the functions used for reporting back to the user
N ProSHADE_internal_misc | This namespace contains all the miscellaneous functions used throughout the code but unrelated to it
N ProSHADE_internal_overlay | This namespace contains all the functions required for map overlays
N ProSHADE_internal_peakSearch | This namespace contains all the functions required for peak searching in 3D maps
N ProSHADE_internal_precomputedVals | This namespace contains the pre-computed values for the ProSHADE run
N ProSHADE_internal_spheres | This namespace contains the structure and functions required for storing internal map projections onto a set of concentric spheres
N ProSHADE_internal_sphericalHarmonics | This namespace contains the internal functions for computing spherical harmonics and their related computations
N ProSHADE_internal_symmetry | This namespace contains the symmetry detection related code
N ProSHADE_internal_tasks | This namespace contains the main driving functions for each task
N ProSHADE_internal_wigner | This namespace contains all the functionality required to perform object rotation in SO(3) space